{% extends "admin/base_site.html" %}
{% load i18n static %}
{% load admin_urls %}

{% block extrastyle %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">{% endblock %}
{% block bodyclass %}{{ block.super }} {{ opts.app_label }}-{{ opts.model_name }} change-form{% endblock %}
{% if not is_popup %}
    {% block breadcrumbs %}
        <li class="breadcrumb-item"><a href="{% url 'admin:index' %}">{% translate 'Home' %}</a></li>
        <li class="breadcrumb-item">
            <a href="{% url 'admin:app_list' app_label=opts.app_label %}">
                {{ opts.app_config.verbose_name }}
            </a>
        </li>
        <li class="breadcrumb-item"><a
                href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a></li>
        <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">
            {{ object|truncatewords:"18" }}</a></li>
        <li class="breadcrumb-item active" aria-current="page">
            {% blocktranslate with escaped_object=object %}
                Change {{ object_name }} password "{{ escaped_object }}"
            {% endblocktranslate %}
        </li>
    {% endblock %}

{% endif %}
{% block content %}
    <div id="content-main">
        <form{% if form_url %} action="{{ form_url }}"{% endif %} method="post" id="{{ opts.model_name }}_form">
            {% csrf_token %}{% block form_top %}{% endblock %}
            <input type="text" name="username" value="{{ original.get_username }}" class="hidden">
            <div>
                {% if is_popup %}<input type="hidden" name="_popup" value="1">{% endif %}
                {% if form.errors %}
                    <p class="errornote">
                        {% if form.errors.items|length == 1 %}
                            {% translate "Please correct the error below." %}{% else %}
                            {% translate "Please correct the errors below." %}{% endif %}
                    </p>
                {% endif %}

                <p>{% blocktranslate with username=original %}Enter a new password for the user
                    <strong>{{ username }}</strong>.{% endblocktranslate %}</p>

                <fieldset class="module aligned">

                    <div class="form-row">
                        {{ form.password1.errors }}
                        {{ form.password1.label_tag }} {{ form.password1 }}
                        {% if form.password1.help_text %}
                            <div class="help">{{ form.password1.help_text|safe }}</div>
                        {% endif %}
                    </div>

                    <div class="form-row">
                        {{ form.password2.errors }}
                        {{ form.password2.label_tag }} {{ form.password2 }}
                        {% if form.password2.help_text %}
                            <div class="help">{{ form.password2.help_text|safe }}</div>
                        {% endif %}
                    </div>

                </fieldset>

                <div class="submit-row">
                    <input type="submit" value="{% translate 'Change password' %}" class="default">
                </div>

            </div>
        </form>
    </div>
{% endblock %}
