{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_list %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/changelists.css" %}">
    {% if cl.formset %}
        <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">
    {% endif %}
    {% if cl.formset or action_form %}
        <script src="{% url 'admin:jsi18n' %}"></script>
    {% endif %}
    {{ media.css }}
    {% if not actions_on_top and not actions_on_bottom %}
        <style>
            #changelist table thead th:first-child {
                width: inherit
            }
        </style>
    {% endif %}
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    {{ media.js }}
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} change-list{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <li class="breadcrumb-item"><a href="{% url 'admin:index' %}">{% translate 'Home' %}</a></li>
        <li class="breadcrumb-item">
            <a href="{% url 'admin:app_list' app_label=cl.opts.app_label %}">
                {{ cl.opts.app_config.verbose_name }}
            </a>
        </li>
        <li class="breadcrumb-item active" aria-current="page">
            {{ cl.opts.verbose_name_plural|capfirst }}
        </li>
    {% endblock %}
{% endif %}

{% block coltype %}{% endblock %}

{% block object-tools %}
    {% block object-tools-items %}
        {% change_list_object_tools %}
    {% endblock %}
{% endblock %}

{% block content %}
    <div id="content-main" class="card">
        <div class="card-content">
            <div class="card-body">
                {% if cl.formset and cl.formset.errors %}
                    <p class="errornote">
                        {% if cl.formset.total_error_count == 1 %}
                            {% translate "Please correct the error below." %}{% else %}
                            {% translate "Please correct the errors below." %}{% endif %}
                    </p>
                    {{ cl.formset.non_form_errors }}
                {% endif %}
                <div class="module{% if cl.has_filters %} filtered{% endif %}" id="changelist">
                    <div class="changelist-form-container">
                        {% block search %}{% search_form cl %}{% endblock %}
                        {% block date_hierarchy %}{% if cl.date_hierarchy %}{% date_hierarchy cl %}
                        {% endif %}{% endblock %}

                        <form id="changelist-form" method="post"{% if cl.formset and cl.formset.is_multipart %}
                              enctype="multipart/form-data"{% endif %} novalidate>{% csrf_token %}
                            {% if cl.formset %}
                                <div>{{ cl.formset.management_form }}</div>
                            {% endif %}

                            {% block result_list %}
                                {% if action_form and actions_on_top and cl.show_admin_actions %}
                                    {% admin_actions %}{% endif %}
                                {% result_list cl %}
                                {% if action_form and actions_on_bottom and cl.show_admin_actions %}
                                    {% admin_actions %}{% endif %}
                            {% endblock %}
                            {% block pagination %}{% pagination cl %}{% endblock %}
                        </form>
                    </div>
                    {% block filters %}
                        {% if cl.has_filters %}
                            <div id="changelist-filter">
                                <h2>{% translate 'Filter' %}</h2>
                                {% if cl.has_active_filters %}<h3 id="changelist-filter-clear">
                                    <a href="{{ cl.clear_all_filters_qs }}">&#10006; {% translate "Clear all filters" %}</a>
                                </h3>{% endif %}
                                {% for spec in cl.filter_specs %}{% admin_list_filter cl spec %}{% endfor %}
                            </div>
                        {% endif %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
