{% load i18n admin_urls %}

{% block object-tools-items %}
    {% if has_add_permission %}
        <li class="breadcrumb-item">
            {% url cl.opts|admin_urlname:'add' as add_url %}
            <a href="{% add_preserved_filters add_url is_popup to_field %}"
               class="addlink btn btn-outline-success rounded-pill btn-sm px-4">
                {% blocktranslate with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktranslate %}
            </a>
        </li>
    {% endif %}
{% endblock %}
