{% load i18n static %}<!DOCTYPE html>
<html>
<head><title>{% translate 'Popup closing…' %}</title></head>
<body>
<script id="django-admin-popup-response-constants"
        src="{% static "admin/js/popup_response.js" %}"
        data-popup-response="{{ popup_response_data }}">
</script>
</body>
</html>
