.sorting .hahahahahaha {
  cursor: pointer;
}
.alert {
  border: none;
}
.alert p {
  margin-bottom: 0;
}
.alert button.close {
  line-height: 0.75;
  padding: 0.75rem;
}
.alert .alert-heading,
.alert .alert-heading + p {
  margin-left: 0.4rem;
}
.alert-primary {
  background-color: #435ebe;
  color: #fff;
}
.alert-primary a {
  color: #fff;
  font-weight: 700;
}
.alert-secondary {
  background-color: #ebeef3;
  color: #383d41;
}
.alert-secondary a {
  color: #fff;
  font-weight: 700;
}
.alert-success {
  background-color: #4fbe87;
  color: #fff;
}
.alert-success a {
  color: #fff;
  font-weight: 700;
}
.alert-warning {
  background-color: #eaca4a;
  color: #fff;
}
.alert-warning a {
  color: #fff;
  font-weight: 700;
}
.alert-danger {
  background-color: #f3616d;
  color: #fff;
}
.alert-danger a {
  color: #fff;
  font-weight: 700;
}
.alert-dark {
  background-color: #454546;
  color: #fff;
}
.alert-dark a {
  color: #fff;
  font-weight: 700;
}
.alert-light {
  background-color: #f9f9f9;
  color: #818182;
}
.alert-light a {
  color: #fff;
  font-weight: 700;
}
.alert-info {
  background-color: #56b6f7;
  color: #fff;
}
.alert-info a {
  color: #fff;
  font-weight: 700;
}
.alert-light-primary {
  background-color: #ebf3ff;
}
.alert-light-secondary {
  background-color: #e6eaee;
}
.alert-light-success {
  background-color: #d2ffe8;
}
.alert-light-danger {
  background-color: #ffdede;
}
.alert-light-warning {
  background-color: #fffdd8;
}
.alert-light-info {
  background-color: #e6fdff;
}
.avatar {
  border-radius: 50%;
  display: inline-flex;
  position: relative;
  text-align: center;
  vertical-align: middle;
}
.avatar .avatar-content {
  align-items: center;
  color: #fff;
  display: flex;
  font-size: 0.875rem;
  height: 32px;
  justify-content: center;
  width: 32px;
}
.avatar .avatar-content i,
.avatar .avatar-content svg {
  color: #fff;
  font-size: 1rem;
  height: 1rem;
}
.avatar img {
  border-radius: 50%;
  height: 32px;
  width: 32px;
}
.avatar .avatar-status {
  border: 1px solid #fff;
  border-radius: 50%;
  bottom: 0;
  height: 0.7rem;
  position: absolute;
  right: 0;
  width: 0.7rem;
}
.avatar.avatar-sm .avatar-content,
.avatar.avatar-sm img {
  font-size: 0.8rem;
  height: 24px;
  width: 24px;
}
.avatar.avatar-md .avatar-content,
.avatar.avatar-md img {
  font-size: 0.8rem;
  height: 32px;
  width: 32px;
}
.avatar.avatar-lg .avatar-content,
.avatar.avatar-lg img {
  font-size: 1.2rem;
  height: 48px;
  width: 48px;
}
.avatar.avatar-xl .avatar-content,
.avatar.avatar-xl img {
  font-size: 1.4rem;
  height: 60px;
  width: 60px;
}
.btn .badge {
  border-radius: 50%;
  margin-left: 5px;
}
.btn .badge.bg-transparent {
  background-color: hsla(0, 0%, 100%, 0.25) !important;
  color: #fff;
}
.btn i,
.btn svg {
  height: 16px;
  width: 16px;
}
.btn.icon {
  padding: 0.4rem 0.6rem;
}
.btn.icon svg {
  height: 16px;
  width: 16px;
}
.btn.icon.icon-left svg {
  margin-right: 3px;
}
.btn.icon.icon-right svg {
  margin-left: 3px;
}
.btn.btn-outline-white {
  border-color: #fff;
  color: #fff;
}
.btn.btn-outline-white:hover {
  background-color: #fff;
  color: #333;
}
.btn.btn-light-primary {
  background-color: #ebf3ff;
  color: #002152;
}
.btn.btn-light-secondary {
  background-color: #e6eaee;
  color: #181e24;
}
.btn.btn-light-success {
  background-color: #d2ffe8;
  color: #00391c;
}
.btn.btn-light-danger {
  background-color: #ffdede;
  color: #450000;
}
.btn.btn-light-warning {
  background-color: #fffdd8;
  color: #3f3c00;
}
.btn.btn-light-info {
  background-color: #e6fdff;
  color: #00474d;
}
.btn.btn-danger,
.btn.btn-info,
.btn.btn-primary,
.btn.btn-secondary,
.btn.btn-success,
.btn.btn-warning {
  color: #fff;
}
.btn.btn-light {
  color: #607080;
}
.btn.btn-dark {
  color: #fff;
}
.btn-block {
  width: 100%;
}
.btn-group:not(.dropdown) .btn:not([class*='btn-']) {
  border: 1px solid #dfe3e7;
}
.btn-group > .btn {
  border-radius: 0.267rem;
}
.buttons .btn {
  margin: 0 10px 10px 0;
}
.breadcrumb.breadcrumb-right {
  justify-content: flex-end;
  margin-top: 1rem;
}
.breadcrumb.breadcrumb-center {
  justify-content: center;
  margin-top: 1rem;
}
.carousel-inner {
  border-radius: 0.7rem;
}
.carousel-caption h5 {
  color: #fff;
}
.card {
  border: none;
  margin-bottom: 2.2rem;
}
.card.card-statistic {
  background: linear-gradient(180deg, #25a6f1, #54b9ff);
  box-shadow: 1px 2px 5px rgba(47, 170, 244, 0.5);
}
.card.card-statistic .card-title {
  color: #fff;
  font-size: 1.3rem;
  font-weight: 400;
  letter-spacing: 0.8px;
  margin-bottom: 0;
  margin-top: 5px;
  text-transform: uppercase;
}
.card.card-statistic .card-right p {
  color: #fff;
  font-size: 1.5rem;
  margin-bottom: 0;
}
.card.card-statistic .card-right span.green {
  color: #6fff6f;
}
.card.card-statistic .card-right span.red {
  color: #ff7979;
}
.card.card-statistic .chart-wrapper {
  height: 100px;
}
.card .card-header {
  border: none;
}
.card .card-header h4 {
  font-size: 1.2rem;
  font-weight: 700;
}
.card .card-header ~ .card-body {
  padding-top: 0;
}
.card .card-content {
  position: relative;
}
.card .card-title {
  font-size: 1.2rem;
}
.card .card-body {
  padding: 1rem;
}
.card .card-heading {
  color: #555;
  font-size: 1.5rem;
}
.card .card-img-overlay {
  background-color: rgba(0, 0, 0, 0.6);
}
.card .card-img-overlay p {
  color: #eee;
}
.card .card-img-overlay .card-title {
  color: #fff;
}
.pricing .card {
  border-right: 1px solid #e9ecef;
  box-shadow: none;
  box-shadow: 0 10px 10px #e9ecef;
  margin-bottom: 0.5rem;
}
.pricing h1 {
  font-size: 4rem;
  margin-bottom: 3rem;
  text-align: center;
}
.pricing .card-header .card-title {
  font-size: 2rem !important;
  margin-bottom: 0;
}
.pricing .card-header p {
  font-size: 0.8rem;
}
.pricing ul li {
  list-style: none;
  margin-bottom: 0.5rem;
}
.pricing ul li i,
.pricing ul li svg {
  color: #198754;
  font-size: 1rem;
  margin-right: 7px;
  width: 1rem;
}
.pricing .card-highlighted {
  background-color: #435ebe;
  padding-bottom: 20px;
  padding-top: 20px;
}
.pricing .card-highlighted .card-body,
.pricing .card-highlighted .card-header {
  background-color: #435ebe;
  color: #fff;
}
.pricing .card-highlighted ul li {
  color: #fff;
}
.pricing .card-highlighted ul li i,
.pricing .card-highlighted ul li svg {
  color: #479f76;
}
.pricing .card-highlighted .card-footer {
  background-color: #435ebe;
}
.pricing .card-highlighted .card-title {
  color: #fff;
  font-size: 1.8rem;
}
.divider {
  display: block;
  margin: 1rem 0;
  overflow: hidden;
  text-align: center;
}
.divider .divider-text {
  background-color: #fff;
  display: inline-block;
  padding: 0 1rem;
  position: relative;
}
.divider .divider-text:after,
.divider .divider-text:before {
  border-top: 1px solid #dfe3e7;
  content: '';
  position: absolute;
  top: 50%;
  width: 9999px;
}
.divider .divider-text:before {
  right: 100%;
}
.divider .divider-text:after {
  left: 100%;
}
.divider.divider-left .divider-text {
  float: left;
  left: 0;
  padding-left: 0;
}
.divider.divider-left-center .divider-text {
  left: -25%;
}
.divider.divider-right-center .divider-text {
  left: 25%;
}
.divider.divider-right .divider-text {
  float: right;
  padding-right: 0;
}
.dropdown-toggle:after {
  color: #fff;
}
.dropdown-menu-large {
  min-width: 16rem;
}
.dropdown-menu {
  box-shadow: 0 0 30px rgba(0, 0, 0, 0.03);
}
.dropdown-item {
  transition: all 0.5s;
}
.form-group {
  margin-bottom: 0.7rem;
}
.form-group label {
  color: rgba(35, 28, 99, 0.7);
  font-weight: 600;
}
.form-group small {
  font-size: 0.7rem;
}
.form-group.with-title {
  position: relative;
}
.form-group.with-title label {
  background-color: #e9ecef;
  font-size: 0.6rem;
  left: 0;
  padding: 5px;
  position: absolute;
  top: 0;
  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
  width: 100%;
}
.form-group.with-title .form-control,
.form-group.with-title dataTable-input {
  padding-top: 2rem;
}
.form-group.with-title .form-control:focus ~ label,
.form-group.with-title dataTable-input:focus ~ label {
  border-left: 1px solid #435ebe;
  border-right: 1px solid #435ebe;
  border-top: 1px solid #435ebe;
}
.form-group[class*='has-icon-'].has-icon-left .form-control {
  padding-left: 2.5rem;
}
.form-group[class*='has-icon-'].has-icon-left .form-control-icon {
  left: 0;
}
.form-group[class*='has-icon-'].has-icon-right .form-control {
  padding-right: 2.5rem;
}
.form-group[class*='has-icon-'].has-icon-right .form-control-icon {
  right: 0;
}
.form-group[class*='has-icon-'] .form-control:focus ~ .form-control-icon i,
.form-group[class*='has-icon-'] .form-control:focus ~ .form-control-icon svg {
  color: #5a8dee;
}
.form-group[class*='has-icon-'] .form-control.form-control-xl {
  padding-left: 3rem;
}
.form-group[class*='has-icon-']
  .form-control.form-control-xl
  ~ .form-control-icon
  i {
  font-size: 1.6rem;
}
.form-group[class*='has-icon-']
  .form-control.form-control-xl
  ~ .form-control-icon
  i:before {
  color: #a6a8aa;
}
.form-group[class*='has-icon-'] .form-control-icon {
  padding: 0 0.6rem;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}
.form-group[class*='has-icon-'] .form-control-icon i,
.form-group[class*='has-icon-'] .form-control-icon svg {
  color: #6c757d;
  font-size: 1.2rem;
  width: 1.2rem;
}
.form-group[class*='has-icon-'] .form-control-icon i:before,
.form-group[class*='has-icon-'] .form-control-icon svg:before {
  vertical-align: sub;
}
.form-control.form-control-xl {
  font-size: 1.2rem;
  padding: 0.85rem 1rem;
}
.form-check .form-check-input[class*='bg-'] {
  border: 0;
}
.form-check .form-check-input:focus {
  box-shadow: none;
}
.form-check .form-check-input.form-check-primary {
  background-color: #435ebe;
  border-color: #435ebe;
}
.form-check .form-check-input.form-check-primary:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-primary.form-check-glow {
  box-shadow: 0 0 5px #697ecb;
}
.form-check .form-check-input.form-check-primary.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-secondary {
  background-color: #6c757d;
  border-color: #6c757d;
}
.form-check .form-check-input.form-check-secondary:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-secondary.form-check-glow {
  box-shadow: 0 0 5px #868e96;
}
.form-check
  .form-check-input.form-check-secondary.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-success {
  background-color: #198754;
  border-color: #198754;
}
.form-check .form-check-input.form-check-success:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-success.form-check-glow {
  box-shadow: 0 0 5px #21b26f;
}
.form-check .form-check-input.form-check-success.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-info {
  background-color: #0dcaf0;
  border-color: #0dcaf0;
}
.form-check .form-check-input.form-check-info:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-info.form-check-glow {
  box-shadow: 0 0 5px #3cd5f4;
}
.form-check .form-check-input.form-check-info.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-warning {
  background-color: #ffc107;
  border-color: #ffc107;
}
.form-check .form-check-input.form-check-warning:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-warning.form-check-glow {
  box-shadow: 0 0 5px #ffce3a;
}
.form-check .form-check-input.form-check-warning.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-danger {
  background-color: #dc3545;
  border-color: #dc3545;
}
.form-check .form-check-input.form-check-danger:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-danger.form-check-glow {
  box-shadow: 0 0 5px #e4606d;
}
.form-check .form-check-input.form-check-danger.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-light {
  background-color: #f8f9fa;
  border-color: #f8f9fa;
}
.form-check .form-check-input.form-check-light:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-light.form-check-glow {
  box-shadow: 0 0 5px #fff;
}
.form-check .form-check-input.form-check-light.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check .form-check-input.form-check-dark {
  background-color: #212529;
  border-color: #212529;
}
.form-check .form-check-input.form-check-dark:not(:checked) {
  background-color: transparent;
  border: 1px solid #ced4da;
}
.form-check .form-check-input.form-check-dark.form-check-glow {
  box-shadow: 0 0 5px #383f45;
}
.form-check .form-check-input.form-check-dark.form-check-glow:not(:checked) {
  box-shadow: none;
}
.form-check.form-check-sm .form-check-input {
  height: 0.9rem;
  margin-top: 0.3em;
  width: 0.9rem;
}
.form-check.form-check-sm label {
  font-size: 0.7rem;
}
.form-check.form-check-lg .form-check-input {
  height: 1.5rem;
  margin-top: 0.3em;
  width: 1.5rem;
}
.form-check.form-check-lg label {
  font-size: 1rem;
}
.form-check.form-check-primary .form-check-input {
  background-color: #435ebe;
  border-color: #435ebe;
}
.form-check.form-check-secondary .form-check-input {
  background-color: #6c757d;
  border-color: #6c757d;
}
.form-check.form-check-success .form-check-input {
  background-color: #198754;
  border-color: #198754;
}
.form-check.form-check-info .form-check-input {
  background-color: #0dcaf0;
  border-color: #0dcaf0;
}
.form-check.form-check-warning .form-check-input {
  background-color: #ffc107;
  border-color: #ffc107;
}
.form-check.form-check-danger .form-check-input {
  background-color: #dc3545;
  border-color: #dc3545;
}
.form-check.form-check-light .form-check-input {
  background-color: #f8f9fa;
  border-color: #f8f9fa;
}
.form-check.form-check-dark .form-check-input {
  background-color: #212529;
  border-color: #212529;
}
.dataTable-input {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  background-clip: padding-box;
  background-color: #fff;
  border: 1px solid #dfe3e7;
  border-radius: 0.25rem;
  color: #555252;
  font-size: 0.9025rem;
  font-weight: 400;
  line-height: 1.5;
  min-height: calc(1.5em + 0.934rem + 2px);
  padding: 0.467rem 0.6rem;
  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}
.dataTable-input:focus {
  background-color: #fff;
  border-color: #5a8dee;
  box-shadow: 0 3px 8px 0 rgba(0, 0, 0, 0.1);
  color: #555252;
  outline: 0;
}
.modal .modal-content {
  border: none;
  box-shadow: -8px 12px 18px 0 rgba(25, 42, 70, 0.13);
}
.modal .modal-full {
  max-width: 94%;
}
.modal .white {
  color: #fff;
}
.modal .modal-header {
  align-items: center;
  display: flex;
  justify-content: space-between;
}
.modal .modal-header .modal-title {
  font-size: 1.1rem;
}
.modal .modal-header .close {
  background: none;
  border: none;
  border-radius: 50%;
  padding: 7px 10px;
}
.modal .modal-header .close:hover {
  background: #dee2e6;
}
.modal .modal-header i,
.modal .modal-header svg {
  font-size: 12px;
  height: 12px;
  width: 12px;
}
.modal .modal-footer {
  padding: 1rem;
}
.modal.modal-borderless .modal-header {
  border-bottom: 0;
}
.modal.modal-borderless .modal-footer {
  border-top: 0;
}
#sidebar.active .sidebar-wrapper {
  left: 0;
}
#sidebar:not(.active) .sidebar-wrapper {
  left: -250px;
}
#sidebar:not(.active) ~ #main {
  margin-left: 0;
}
.sidebar-wrapper {
  background-color: #fff;
  bottom: 0;
  height: 100vh;
  overflow-y: auto;
  position: fixed;
  top: 0;
  transition: left 0.5s ease-out;
  width: 250px;
  z-index: 10;
}
.sidebar-wrapper .sidebar-header {
  font-size: 1.2rem;
  text-align: center;
  font-weight: 700;
  padding: 2rem 2rem 1rem;
}
.sidebar-wrapper .sidebar-header img {
  height: 1.2rem;
}
.sidebar-wrapper .sidebar-toggler.x {
  display: none;
  position: absolute;
  right: 0;
  top: 0.5rem;
}
.sidebar-wrapper .menu {
  font-weight: 600;
  margin-top: 2rem;
  padding: 0 2rem;
}
.sidebar-wrapper .menu .sidebar-title {
  color: #25396f;
  font-size: 1rem;
  font-weight: 600;
  list-style: none;
  margin: 1.5rem 0 1rem;
  padding: 0 1rem;
}
.sidebar-wrapper .menu .sidebar-link {
  align-items: center;
  border-radius: 0.5rem;
  color: #25396f;
  display: block;
  display: flex;
  font-size: 1rem;
  padding: 0.7rem 1rem;
  text-decoration: none;
  transition: all 0.5s;
}
.sidebar-wrapper .menu .sidebar-link i,
.sidebar-wrapper .menu .sidebar-link svg {
  color: #7c8db5;
}
.sidebar-wrapper .menu .sidebar-link span {
  margin-left: 1rem;
}
.sidebar-wrapper .menu .sidebar-link:hover {
  background-color: #f0f1f5;
}
.sidebar-wrapper .menu .sidebar-item {
  list-style: none;
  margin-top: 0.5rem;
  position: relative;
}
.sidebar-wrapper .menu .sidebar-item.has-sub .sidebar-link:after {
  color: #ccc;
  content: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down"><path style="fill:none;stroke:gray;stroke-width:1" d="m6 9 6 6 6-6"/></svg>');
  display: block;
  position: absolute;
  right: 1px;
  top: 12px;
}
.sidebar-wrapper .menu .sidebar-item.active .sidebar-link {
  background-color: #435ebe;
}
.sidebar-wrapper .menu .sidebar-item.active .sidebar-link span {
  color: #fff;
}
.sidebar-wrapper .menu .sidebar-item.active .sidebar-link i,
.sidebar-wrapper .menu .sidebar-item.active .sidebar-link svg {
  fill: #fff;
  color: #fff;
}
.sidebar-wrapper .menu .sidebar-item.active .sidebar-link.has-sub:after {
  content: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down"><path style="fill:none;stroke:%23fff;stroke-width:1" d="m6 9 6 6 6-6"/></svg>');
}
.sidebar-wrapper .menu .submenu {
  display: none;
  list-style: none;
  overflow: hidden;
  transition: max-height 2s cubic-bezier(0, 0.55, 0.45, 1);
}
.sidebar-wrapper .menu .submenu.active {
  display: block;
  max-height: 999px;
}
.sidebar-wrapper .menu .submenu .submenu-item.active {
  position: relative;
}
.sidebar-wrapper .menu .submenu .submenu-item.active > a {
  color: #435ebe;
  font-weight: 700;
}
.sidebar-wrapper .menu .submenu .submenu-item a {
  color: #25396f;
  display: block;
  font-size: 0.85rem;
  font-weight: 600;
  letter-spacing: 0.5px;
  padding: 0.7rem 1rem;
  transition: all 0.3s;
}
.sidebar-wrapper .menu .submenu .submenu-item a:hover {
  margin-left: 0.3rem;
}
@media screen and (max-width: 1199px) {
  .sidebar-wrapper {
    left: -250px;
    position: absolute;
  }
  .sidebar-wrapper .sidebar-toggler.x {
    display: block;
  }
}
.nav-pills .nav-link.active {
  box-shadow: 0 2px 10px rgba(67, 94, 190, 0.5);
}
.nav-tabs,
.nav-tabs .nav-link {
  border: none;
}
.nav-tabs .nav-link:hover {
  border: none;
  text-shadow: 0 0 2px rgba(67, 94, 190, 0.3);
}
.nav-tabs .nav-link.active {
  border: none;
  color: #435ebe;
  position: relative;
}
.nav-tabs .nav-link.active:after {
  background-color: #435ebe;
  bottom: 0;
  box-shadow: 0 2px 5px rgba(67, 94, 190, 0.5);
  content: '';
  height: 2px;
  left: 0;
  position: absolute;
  width: 100%;
}
.navbar-fixed {
  background-color: #fff;
  position: fixed;
}
.navbar {
  height: 90px;
  padding: 1.5rem;
}
.navbar .navbar-brand img {
  height: 1.5rem;
}
.navbar .user-menu img {
  height: 39px;
  width: 39px;
}
.navbar.navbar-header li {
  align-items: center;
  display: flex;
}
.navbar.navbar-header li.nav-icon {
  margin-right: 0.4rem;
}
.navbar.navbar-header li.nav-icon .nav-link {
  border-radius: 50%;
  display: block;
  padding: 0.4rem;
}
.navbar.navbar-header li.nav-icon .nav-link:hover {
  background-color: #e9ecef;
}
.navbar.navbar-header .dropdown > a {
  color: #6c757d;
  font-weight: 600;
}
.navbar.navbar-header .dropdown > a svg {
  height: 24px;
  width: 24px;
}
.navbar.navbar-header .dropdown > a:after {
  display: none;
}
.pagination.pagination-primary .page-item.active .page-link {
  background-color: #435ebe;
  border-color: #435ebe;
  box-shadow: 0 2px 5px rgba(67, 94, 190, 0.3);
}
.pagination.pagination-secondary .page-item.active .page-link {
  background-color: #6c757d;
  border-color: #6c757d;
  box-shadow: 0 2px 5px hsla(208, 7%, 46%, 0.3);
}
.pagination.pagination-success .page-item.active .page-link {
  background-color: #198754;
  border-color: #198754;
  box-shadow: 0 2px 5px rgba(25, 135, 84, 0.3);
}
.pagination.pagination-info .page-item.active .page-link {
  background-color: #0dcaf0;
  border-color: #0dcaf0;
  box-shadow: 0 2px 5px rgba(13, 202, 240, 0.3);
}
.pagination.pagination-warning .page-item.active .page-link {
  background-color: #ffc107;
  border-color: #ffc107;
  box-shadow: 0 2px 5px rgba(255, 193, 7, 0.3);
}
.pagination.pagination-danger .page-item.active .page-link {
  background-color: #dc3545;
  border-color: #dc3545;
  box-shadow: 0 2px 5px rgba(220, 53, 69, 0.3);
}
.pagination.pagination-light .page-item.active .page-link {
  background-color: #f8f9fa;
  border-color: #f8f9fa;
  box-shadow: 0 2px 5px rgba(248, 249, 250, 0.3);
}
.pagination.pagination-dark .page-item.active .page-link {
  background-color: #212529;
  border-color: #212529;
  box-shadow: 0 2px 5px rgba(33, 37, 41, 0.3);
}
.page-item:not(.active) .page-link:hover {
  color: #000;
}
.page-item i,
.page-item svg {
  font-size: 13px;
  height: 13px;
  width: 13px;
}
.page-item .page-link {
  font-size: 0.875rem;
}
.page-item .page-link:focus {
  box-shadow: none;
}
.page-item:first-child {
  margin-right: 0.4rem;
}
.page-item:last-child {
  margin-left: 0.4rem;
}
.dataTable-table td,
.dataTable-table thead th,
.table td,
.table thead th {
  vertical-align: middle;
}
.dataTable-table:not(.table-borderless) thead th,
.table:not(.table-borderless) thead th {
  border-bottom: 1px solid #dedede !important;
}
.table-md.dataTable-table tr td,
.table-md.dataTable-table tr th,
.table-sm.dataTable-table tr td,
.table-sm.dataTable-table tr th,
.table.table-md tr td,
.table.table-md tr th,
.table.table-sm tr td,
.table.table-sm tr th {
  padding: 1rem;
}
.table-lg.dataTable-table tr td,
.table-lg.dataTable-table tr th,
.table.table-lg tr td,
.table.table-lg tr th {
  padding: 1.3rem;
}
.dataTable-container {
  overflow-x: auto;
}
.progress.progress-primary {
  overflow: visible;
}
.progress.progress-primary .progress-bar {
  background-color: #435ebe;
  border-radius: 0.25rem;
}
.progress.progress-secondary {
  overflow: visible;
}
.progress.progress-secondary .progress-bar {
  background-color: #6c757d;
  border-radius: 0.25rem;
}
.progress.progress-success {
  overflow: visible;
}
.progress.progress-success .progress-bar {
  background-color: #198754;
  border-radius: 0.25rem;
}
.progress.progress-info {
  overflow: visible;
}
.progress.progress-info .progress-bar {
  background-color: #0dcaf0;
  border-radius: 0.25rem;
}
.progress.progress-warning {
  overflow: visible;
}
.progress.progress-warning .progress-bar {
  background-color: #ffc107;
  border-radius: 0.25rem;
}
.progress.progress-danger {
  overflow: visible;
}
.progress.progress-danger .progress-bar {
  background-color: #dc3545;
  border-radius: 0.25rem;
}
.progress.progress-light {
  overflow: visible;
}
.progress.progress-light .progress-bar {
  background-color: #f8f9fa;
  border-radius: 0.25rem;
}
.progress.progress-dark {
  overflow: visible;
}
.progress.progress-dark .progress-bar {
  background-color: #212529;
  border-radius: 0.25rem;
}
.progress.progress-sm {
  height: 0.4rem;
}
.progress.progress-lg {
  height: 1.5rem;
}
.progress .progress-bar {
  overflow: visible;
  position: relative;
}
.progress .progress-bar.progress-label:before {
  color: #495057;
  content: attr(aria-valuenow) '%';
  font-size: 0.8rem;
  position: absolute;
  right: 0;
  top: -1.3rem;
}
.bi {
  height: 1rem;
  width: 1rem;
}
.bi.bi-middle:before {
  vertical-align: middle;
}
.bi.bi-sub:before {
  vertical-align: sub;
}
.stats-icon {
  align-items: center;
  background-color: #000;
  border-radius: 0.5rem;
  display: flex;
  float: right;
  height: 3rem;
  justify-content: center;
  width: 3rem;
}
.stats-icon i {
  color: #fff;
  font-size: 1.7rem;
}
.stats-icon.purple {
  background-color: #9694ff;
}
.stats-icon.blue {
  background-color: #57caeb;
}
.stats-icon.red {
  background-color: #ff7976;
}
.stats-icon.green {
  background-color: #5ddab4;
}
@media (max-width: 767px) {
  .stats-icon {
    float: left;
    margin-bottom: 0.4rem;
  }
}
.burger-btn {
  display: none;
}
#main {
  margin-left: 250px;
  padding: 2rem;
}
@media screen and (max-width: 1199px) {
  #main {
    margin-left: 0;
    padding: 0;
  }
}
#main.layout-navbar {
  padding: 0;
}
#main #main-content {
  padding: 2rem;
}
.page-heading {
  margin: 0 0 2rem;
}
.page-heading h3 {
  font-weight: 700;
}
.page-title-headings {
  align-items: center;
  display: flex;
  justify-content: space-between;
  margin-bottom: 0.5rem;
}
.page-title-headings h3 {
  margin-bottom: 0;
  margin-right: 1rem;
}
.page-title-headings .breadcrumb {
  margin-bottom: 0;
}
a {
  text-decoration: none;
}
.mt-10 {
  margin-top: 3rem;
}
.mb-10,
.my-10 {
  margin-bottom: 3rem;
}
.my-10 {
  margin-top: 3rem;
}
.mb-24,
.my-24 {
  margin-bottom: 6rem;
}
.my-24 {
  margin-top: 6rem;
}
.opacity-50 {
  opacity: 50%;
}
.py-4-5 {
  padding-bottom: 2rem !important;
  padding-top: 2rem !important;
}
.text-sm {
  font-size: 0.875rem;
}
.text-xl {
  font-size: 1.25rem;
}
.text-4xl {
  font-size: 2.25rem;
}
.text-6xl {
  font-size: 4rem;
}
.text-black {
  color: #000;
}
.bg-gradient-ltr {
  background: linear-gradient(90deg, #095cde, #53c3f3);
}
.bg-light-purple {
  background-color: #cc90ff;
  color: #002152;
}
.bg-light-magenta {
  background-color: #ff90ff;
  color: #002152;
}
.bg-light-primary {
  background-color: #ebf3ff;
  color: #002152;
}
.bg-light-secondary {
  background-color: #e6eaee;
  color: #181e24;
}
.bg-light-success {
  background-color: #d2ffe8;
  color: #00391c;
}
.bg-light-danger {
  background-color: #ffdede;
  color: #450000;
}
.bg-light-warning {
  background-color: #fffdd8;
  color: #3f3c00;
}
.bg-light-info {
  background-color: #e6fdff;
  color: #00474d;
}
.font-semibold {
  font-weight: 600;
}
.font-bold {
  font-weight: 700;
}
.font-extrabold {
  font-weight: 800;
}
.text-width-md {
  max-width: 450px;
}
.text-gray-300 {
  color: #dee2e6 !important;
}
.text-gray-400 {
  color: #ced4da !important;
}
.text-gray-500 {
  color: #adb5bd !important;
}
.text-gray-600 {
  color: #6c757d !important;
}
.btn-xl {
  padding: 1rem 2rem;
}
.icon-mid:before {
  vertical-align: middle;
}
.row {
  width: 100%;
}
.table {
  vertical-align: middle;
}
.card .card-body .card-header {
  padding: 1.5rem 0;
}
body {
  min-width: 320px;
}
.bg-info,
.bg-info > a {
  color: #fff !important;
}
.card-header:first-child {
  border-radius: 0.7rem;
}
.timeline {
  margin: 0 0 45px;
  padding: 0;
  position: relative;
}
.timeline::before {
  border-radius: 0.25rem;
  background-color: #dee2e6;
  bottom: 0;
  content: '';
  left: 13px;
  margin: 0;
  position: absolute;
  top: 0;
  width: 4px;
}
.timeline > div {
  margin-bottom: 15px;
  margin-right: 10px;
  position: relative;
}
.timeline > div::after,
.timeline > div::before {
  content: '';
  display: table;
}
.timeline > div > .bi {
  color: white;
  background-color: #adb5bd;
  border-radius: 50%;
  font-size: 16px;
  height: 30px;
  line-height: 30px;
  position: absolute;
  text-align: center;
  top: 0;
  width: 30px;
  padding: 3px;
}
.timeline-item {
  word-break: break-word;
}
.timeline > div > .timeline-item {
  box-shadow: 0 0 1px rgb(0 0 0 / 13%), 0 1px 3px rgb(0 0 0 / 20%);
  border-radius: 0.25rem;
  background-color: #fff;
  color: #495057;
  margin-left: 40px;
  margin-top: 0;
  padding: 0;
  position: relative;
}
.timeline > div > .timeline-item > .time {
  color: #999;
  float: left;
  font-size: 12px;
  padding: 10px;
  width: 100%;
}
.timeline > div > .timeline-item > .timeline-header {
  border-bottom: 1px solid rgba(0, 0, 0, 0.125);
  color: #495057;
  font-size: 16px;
  line-height: 1.1;
  margin: 0;
  padding: 10px;
}
.timeline > div > .timeline-item > .timeline-body,
.timeline > div > .timeline-item > .timeline-footer {
  padding: 10px;
}
.timeline > .time-label > span {
  border-radius: 4px;
  background-color: #fff;
  display: inline-block;
  font-weight: 600;
  padding: 5px;
}
p.datetime {
  line-height: 20px;
  margin: 0;
  /*padding: 0 1.5rem;*/
  color: rgba(35, 28, 99, 0.7);
  font-weight: 600;
}
.datetime input,
.form-row .datetime input.vDateField,
.form-row .datetime input.vTimeField {
  margin-left: 5px;
  margin-bottom: 4px;
}
.vDateField {
  min-width: 6.85em;
}
.vDateField,
.vTimeField {
  display: inline-block;
  margin-right: 2px;
  margin-bottom: 4px;
  width: auto;
}
.vLargeTextField {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  background-clip: padding-box;
  background-color: #fff;
  border: 1px solid #dce7f1;
  border-radius: 0.25rem;
  color: #607080;
  display: block;
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  padding: 0.375rem 0.75rem;
  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
  width: 100%;
}
.date-icon:before,
.clock-icon:before {
  display: inline-block;
  font-family: bootstrap-icons !important;
  font-style: normal;
  font-weight: normal !important;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: '\f214';
  vertical-align: middle;
}

.clock-icon:before {
  content: '\f293';
}
/* CALENDARS & CLOCKS */

.calendarbox,
.clockbox {
  margin: 5px auto;
  font-size: 12px;
  width: 19em;
  text-align: center;
  background: white;
  border: 1px solid #ddd;
  border-radius: 4px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.15);
  overflow: hidden;
  position: relative;
}

.clockbox {
  width: auto;
}

.calendar {
  margin: 0;
  padding: 0;
}

.calendar table {
  margin: 0;
  padding: 0;
  border-collapse: collapse;
  background: white;
  width: 100%;
}

.calendar caption,
.calendarbox h2,
.clockbox h2 {
  margin: 0;
  text-align: center;
  border-top: none;
  background: #f5dd5d;
  font-weight: 700;
  font-size: 12px;
  color: #333;
}

.clockbox h2 {
  font-size: 16px;
  padding: 5px;
}

.calendar th {
  padding: 8px 5px;
  background: #f8f8f8;
  border-bottom: 1px solid #ddd;
  font-weight: 400;
  font-size: 12px;
  text-align: center;
  color: #666;
}

.calendar td {
  font-weight: 400;
  font-size: 12px;
  text-align: center;
  padding: 0;
  border-top: 1px solid #eee;
  border-bottom: none;
}

.calendar td.selected a {
  background: #435ebe;
  color: #fff !important;
}

.calendar td.nonday {
  background: #f8f8f8;
}

.calendar td.today a {
  font-weight: 700;
}

.calendar td a,
.timelist a {
  display: block;
  font-weight: 400;
  padding: 6px;
  text-decoration: none;
  color: #444;
}

.timelist li {
  list-style-type: none;
}

.timelist {
  margin: 0;
  padding: 0;
}

.calendar td a:focus,
.timelist a:focus,
.calendar td a:hover,
.timelist a:hover {
  background: #435ebe;
  color: white;
}

.calendar td a:active,
.timelist a:active {
  background: #435ebe;
  color: white;
}

.calendarnav {
  font-size: 10px;
  text-align: center;
  color: #ccc;
  margin: 0;
  padding: 1px 3px;
}

.calendarnav a:link,
#calendarnav a:visited,
#calendarnav a:focus,
#calendarnav a:hover {
  color: #999;
}

.calendar-shortcuts {
  background: white;
  font-size: 11px;
  line-height: 11px;
  border-top: 1px solid #eee;
  padding: 8px 0;
  color: #ccc;
}

.calendarbox .calendarnav-previous,
.calendarbox .calendarnav-next {
  display: block;
  position: absolute;
  top: 8px;
  width: 15px;
  height: 15px;
  text-indent: -9999px;
  padding: 0;
}

.calendarnav-previous {
  left: 10px;
  background: url(../img/calendar-icons.svg) 0 0 no-repeat;
  background-color: #f8f8f8;
}

.calendarbox .calendarnav-previous:focus,
.calendarbox .calendarnav-previous:hover {
  background-position: 0 -15px;
}

.calendarnav-next {
  right: 10px;
  background: url(../img/calendar-icons.svg) 0 -30px no-repeat;
  background-color: #f8f8f8;
}

.calendarbox .calendarnav-next:focus,
.calendarbox .calendarnav-next:hover {
  background-position: 0 -45px;
}

.calendar-cancel {
  margin: 0;
  padding: 4px 0;
  font-size: 12px;
  background: #eee;
  border-top: 1px solid #ddd;
  color: #333;
}

.calendar-cancel:focus,
.calendar-cancel:hover {
  background: #ddd;
}

.calendar-cancel a {
  color: black;
  display: block;
}

.help-block,
.timezonewarning {
  font-size: 0.8em;
  color: rgba(35, 28, 99, 0.7);
  font-style: italic;
}
@media (max-width: 992px) {
  .block-main {
    order: 2;
  }
  .block-filter {
    order: 1;
  }
}
@media (max-width: 767px) {
  .row {
    margin: 0;
  }
  .row > * {
    padding: 0;
  }
}
@media (max-width: 681px) and (min-width: 576px) {
  .mtmd-2 {
    margin-top: 0.5rem !important;
  }
}
@media (max-width: 575px) {
  .w-es-100 {
    width: 100%;
  }
}
