{% extends "admin/base.html" %}

{% block title %}
    {% if subtitle %}{{ subtitle }} | {% endif %}
    {{ title }} | {{ site_title|default:_('Django site admin')}}
{% endblock %}

{% block branding %}
    <h3 id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a></h3>
{% endblock %}

{% block nav-global %}{% endblock %}
