{% extends "admin/base_site.html" %}
{% load i18n admin_urls static %}

{% block extrahead %}
    {{ block.super }}
    {{ media }}
    <script src="{% static 'admin/js/cancel.js' %}" async></script>
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }}
    delete-confirmation{% endblock %}
{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'admin:index' %}">{% translate 'Home' %}</a></li>
    <li class="breadcrumb-item">
        <a href="{% url 'admin:app_list' app_label=opts.app_label %}">
            {{ opts.app_config.verbose_name }}
        </a>
    </li>
    <li class="breadcrumb-item"><a
            href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a></li>
    <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">
        {{ object|truncatewords:"18" }}</a></li>
    <li class="breadcrumb-item active" aria-current="page">
        {% blocktranslate with escaped_object=object %}
            Delete {{ object_name }} "{{ escaped_object }}"
        {% endblocktranslate %}
    </li>
{% endblock %}

{% block content %}
    {% if perms_lacking %}
        <p>{% blocktranslate with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would
            result in deleting related objects, but your account doesn't have permission to delete the following types
            of objects:{% endblocktranslate %}</p>
        <ul>
            {% for obj in perms_lacking %}
                <li>{{ obj }}</li>
            {% endfor %}
        </ul>
    {% elif protected %}
        <p>{% blocktranslate with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would
            require deleting the following protected related objects:{% endblocktranslate %}</p>
        <ul>
            {% for obj in protected %}
                <li>{{ obj }}</li>
            {% endfor %}
        </ul>
    {% else %}
        <p>{% blocktranslate with escaped_object=object %}Are you sure you want to delete the {{ object_name }}
            "{{ escaped_object }}"? All of the following related items will be deleted:{% endblocktranslate %}</p>
        <div class="card">
            <div class="card-body">
                {% include "admin/includes/object_delete_summary.html" %}
                <h4>{% translate "Objects" %}</h4>
                <ul>{{ deleted_objects|unordered_list }}</ul>
                <form method="post">{% csrf_token %}
                    <div>
                        <input type="hidden" name="post" value="yes">
                        {% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1">{% endif %}
                        {% if to_field %}
                            <input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}">{% endif %}

                        <input type="submit" class="btn btn-danger rounded-pill px-5"
                               value="{% translate 'Yes, I’m sure' %}">
                        <a href="#"
                           class="cancel-link btn btn-outline-secondary rounded-pill px-5">{% translate "No, take me back" %}</a>
                    </div>
                </form>
            </div>
        </div>
    {% endif %}
{% endblock %}
