{% load i18n admin_urls %}
<div class="submit-row">
    {% block submit-row %}


        {% if show_save %}
            <input type="submit" value="{% translate 'Save' %}" class="btn btn-primary rounded-pill px-5" name="_save">
        {% endif %}

        {% if show_save_as_new %}
            <input type="submit" value="{% translate 'Save as new' %}" name="_saveasnew"
                   class="btn btn-primary rounded-pill px-5">
        {% endif %}
        {% if show_save_and_add_another %}
            <input type="submit" value="{% translate 'Save and add another' %}" name="_addanother"
                   class="btn btn-outline-success rounded-pill px-5">
        {% endif %}
        {% if show_save_and_continue %}
            <input type="submit" name="_continue" class="btn btn-outline-secondary rounded-pill px-5" value="{% if can_change %}{% translate 'Save and continue editing' %}{% else %}{% translate 'Save and view' %}{% endif %}">
        {% endif %}
        {% if show_close %}
            <a href="{% url opts|admin_urlname:'changelist' %}"
               class="btn btn-outline-danger rounded-pill px-5">{% translate 'Close' %}</a>
        {% endif %}
        {% if show_delete_link and original %}
            {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
            <a href="{% add_preserved_filters delete_url %}"
               class="btn btn-outline-danger rounded-pill px-5 float-start">{% translate "Delete" %}</a>
        {% endif %}
    {% endblock %}
</div>
