{% extends "admin/base_site.html" %}
{% load i18n admin_urls %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'admin:index' %}">{% translate 'Home' %}</a></li>
    <li class="breadcrumb-item"><a
            href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'changelist' %}">{{ module_name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">
        {{ object|truncatewords:"18" }}</a></li>
    <li class="breadcrumb-item active" aria-current="page">
        {% translate 'History' %}
    </li>
{% endblock %}

{% block content %}
    <div id="content-main" class="card">
        <div class="module card-body">
            {% if action_list %}
                <div class="table-responsive">
                    <table id="change-history" class="table table-xs">
                        <thead>
                        <tr>
                            <th scope="col">{% translate 'Date/time' %}</th>
                            <th scope="col">{% translate 'User' %}</th>
                            <th scope="col">{% translate 'Action' %}</th>
                        </tr>
                        </thead>
                        <tbody>
                        {% for action in action_list %}
                            <tr>
                                <th scope="row">{{ action.action_time|date:"DATETIME_FORMAT" }}</th>
                                <td>{{ action.user.get_username }}{% if action.user.get_full_name %} (
                                    {{ action.user.get_full_name }}){% endif %}</td>
                                <td>{{ action.get_change_message }}</td>
                            </tr>
                        {% endfor %}
                        </tbody>
                    </table>
                </div>
            {% else %}
                <p>{% translate 'This object doesn’t have a change history. It probably wasn’t added via this admin site.' %}</p>
            {% endif %}
        </div>
    </div>
{% endblock %}
